Changelog
---------

0.1.4
~~~~~

* Adds support to latest python and django versions.

0.1.3
~~~~~

* Use number_mode=NM_DECIMAL for loads and dumps.

0.1.2
~~~~~

* Improve tests.

0.1.1
~~~~~

* Remove python 2.7 from setup.py.

0.1.0
~~~~~

* Initial release.
